@@ -88,22 +88,22 @@ typedef marpaESLIFRecognizerEventCallback_t (*marpaESLIFRecognizerEventActionRes
 /* KeyType key                => valueType       value                              key/pair indice */
 /* ------- ---                   ---------       -----                                              */
 /* STRING  "callout_number"   => LONG or UNDEF   Callout number                                   0 */
-/* STRING  "callout_string"   => STRING or UNDEF Callout string                                   1 */
-/* STRING  "subject"          => ARRAY OR UNDEF  Subject (*)                                      2 */
-/* STRING  "pattern"          => STRING OR UNDEF Pattern (*)                                      3 */
+/* STRING  "callout_string"   => ARRAY or UNDEF  Callout string (*)                               1 */
+/* STRING  "subject"          => ARRAY           Subject (*)                                      2 */
+/* STRING  "pattern"          => ARRAY           Pattern (*)                                      3 */
 /* STRING  "capture_top"      => LONG            Max current capture                              4 */
 /* STRING  "capture_last"     => LONG            Most recently closed capture                     5 */
 /* STRING  "offset_vector"    => ROW of LONGs    Offset vector                                    6 */
 /* STRING  "mark"             => LONG or UNDEF   Current mark offset                              7 */
 /* STRING  "start_match"      => LONG            Current match start attempt offset               8 */
 /* STRING  "current_position" => LONG            Current subject offset                           9 */
-/* STRING  "next_item"        => STRING or UNDEF Next item in the pattern                        10 */
+/* STRING  "next_item"        => ARRAY or UNDEF  Next item in the pattern (*)                    10 */
 /* STRING  "grammar_level"    => INT             The grammar level                               11 */
 /* STRING  "symbol_id"        => INT             The symbol identifier                           12 */
 /*                                                                                                  */
-/* (*) By default UNDEF is returned, unless ESLIF is compiled without the MARPAESLIF_NTRACE define. */
-/*     This is voluntarily choice for performance reasons.                                          */
-/*     In production mode ESLIF guarantees that:                                                    */
+/* (*) Direct memory pointer is returned. Any attempt to change the underlying bytes will result    */
+/*     to undefined behaviour.                                                                      */
+/*     ESLIF guarantees that:                                                                       */
 /*     - subject correspond to the output of marpaESLIFRecognizer_input()                           */
 /*     - pattern can be retreived using the symbol's description using symbol_id value in input to  */
 /*       marpaESLIFGrammar_symbolproperty_by_levelb().                                              */
@@ -128,6 +128,24 @@ typedef enum marpaESLIFCalloutBlockEnum {
                                          _MARPAESLIFCALLOUTBLOCK_SIZE
 } marpaESLIFCalloutBlockEnum_t;
 
+/* marpaESLIFCallout table Keys */
+static const char *marpaESLIFCalloutKeysp[_MARPAESLIFCALLOUTBLOCK_SIZE] = {
+  "callout_number",
+  "callout_string",
+  "subject",
+  "pattern",
+  "capture_top",
+  "capture_last",
+  "offset_vector",
+  "mark",
+  "start_match",
+  "current_position",
+  "next_item",
+  "grammar_level",
+  "symbol_id"
+};
+
+
 /* -------------------------------------------------------------------------------- */
 /* You MUST refer to                                                                */
 /* https://www.pcre.org/current/doc/html/pcre2callout.html#calloutinterface         */
@@ -441,6 +459,7 @@ typedef struct marpaESLIFGrammarProperty {
   int                    maxLeveli;               /* Maximum grammar level */
   marpaESLIFString_t    *descp;                   /* Grammar description (auto-generated if none) */
   short                  latmb;                   /* LATM ? */
+  short                  discardIsFallbackb;      /* Discard is fallback ? */
   marpaESLIFAction_t    *defaultSymbolActionp;    /* Default action for symbols - never NULL */
   marpaESLIFAction_t    *defaultRuleActionp;      /* Default action for rules - never NULL */
   marpaESLIFAction_t    *defaultEventActionp;     /* Default action for event - can be NULL */
