@@ -80,6 +80,7 @@
 #define G1_RULE_ADVERB_ITEM_21                   "G1_rule_adverb_item_21"
 #define G1_RULE_ADVERB_ITEM_22                   "G1_rule_adverb_item_22"
 #define G1_RULE_ADVERB_ITEM_23                   "G1_rule_adverb_item_23"
+#define G1_RULE_ADVERB_ITEM_24                   "G1_rule_adverb_item_24"
 #define G1_RULE_ACTION_1                         "G1_rule_action_1"
 #define G1_RULE_ACTION_2                         "G1_rule_action_2"
 #define G1_RULE_ACTION_3                         "G1_rule_action_3"
@@ -110,6 +111,8 @@
 #define G1_RULE_EVENT_INITIALIZER_2              "G1_rule_event_initializer_2"
 #define G1_RULE_LATM_SPECIFICATION_1             "G1_rule_latm_specification_1"
 #define G1_RULE_LATM_SPECIFICATION_2             "G1_rule_latm_specification_2"
+#define G1_RULE_DISCARD_IS_FALLBACK_SPECIFICATION_1 "G1_rule_discard_is_fallback_specification_1"
+#define G1_RULE_DISCARD_IS_FALLBACK_SPECIFICATION_2 "G1_rule_discard_is_fallback_specification_2"
 #define G1_RULE_VERBOSE_SPECIFICATION_1          "G1_rule_verbose_specification_1"
 #define G1_RULE_VERBOSE_SPECIFICATION_2          "G1_rule_verbose_specification_2"
 #define G1_RULE_NAMING                           "G1_rule_naming"
@@ -249,40 +252,40 @@
 #define G1_ACTION_STATEMENT_19                     "::undef"
 #define G1_ACTION_STATEMENT_20                     "::undef"
 #define G1_ACTION_STATEMENT_21                     "::undef"
-#define G1_ACTION_START_RULE                       "G1_action_start_rule"                       /* done */
-#define G1_ACTION_START_SYMBOL_1                   "G1_action_start_symbol_1"                   /* done */
-#define G1_ACTION_START_SYMBOL_2                   "G1_action_start_symbol_2"                   /* done */
-#define G1_ACTION_DESC_RULE                        "G1_action_desc_rule"                        /* done */
-#define G1_ACTION_EMPTY_RULE                       "G1_action_empty_rule"                       /* done */
+#define G1_ACTION_START_RULE                       "063_G1_action_start_rule"                       /* done */
+#define G1_ACTION_START_SYMBOL_1                   "114_G1_action_start_symbol_1"                   /* done */
+#define G1_ACTION_START_SYMBOL_2                   "115_G1_action_start_symbol_2"                   /* done */
+#define G1_ACTION_DESC_RULE                        "064_G1_action_desc_rule"                        /* done */
+#define G1_ACTION_EMPTY_RULE                       "065_G1_action_empty_rule"                       /* done */
 #define G1_ACTION_NULL_STATEMENT                   "::undef"
 #define G1_ACTION_STATEMENT_GROUP                  "::undef"
-#define G1_ACTION_PRIORITY_RULE                    "G1_action_priority_rule"                    /* done */
-#define G1_ACTION_QUANTIFIED_RULE                  "G1_action_quantified_rule"                  /* done */
-#define G1_ACTION_DISCARD_RULE                     "G1_action_discard_rule"                     /* done */
-#define G1_ACTION_DEFAULT_RULE                     "G1_action_default_rule"                     /* done */
-#define G1_ACTION_LEXEME_RULE                      "G1_action_lexeme_rule"                      /* done */
-#define G1_ACTION_TERMINAL_RULE                    "G1_action_terminal_rule"                    /* done */
-#define G1_ACTION_SYMBOL_RULE                      "G1_action_symbol_rule"                      /* done */
-#define G1_ACTION_COMPLETION_EVENT_DECLARATION_1   "G1_action_completion_event_declaration_1"   /* done */
-#define G1_ACTION_COMPLETION_EVENT_DECLARATION_2   "G1_action_completion_event_declaration_2"   /* done */
-#define G1_ACTION_NULLED_EVENT_DECLARATION_1       "G1_action_nulled_event_declaration_1"       /* done */
-#define G1_ACTION_NULLED_EVENT_DECLARATION_2       "G1_action_nulled_event_declaration_2"       /* done */
-#define G1_ACTION_PREDICTED_EVENT_DECLARATION_1    "G1_action_predicted_event_declaration_1"    /* done */
-#define G1_ACTION_PREDICTED_EVENT_DECLARATION_2    "G1_action_predicted_event_declaration_2"    /* done */
-#define G1_ACTION_INACCESSIBLE_STATEMENT           "G1_action_inaccessible_statement"           /* done */
-#define G1_ACTION_INACCESSIBLE_TREATMENT_1         "G1_action_inaccessible_treatment_1"         /* done */
-#define G1_ACTION_INACCESSIBLE_TREATMENT_2         "G1_action_inaccessible_treatment_2"         /* done */
-#define G1_ACTION_INACCESSIBLE_TREATMENT_3         "G1_action_inaccessible_treatment_3"         /* done */
-#define G1_ACTION_EXCEPTION_STATEMENT              "G1_action_exception_statement"
-#define G1_ACTION_AUTORANK_STATEMENT               "G1_action_autorank_statement"               /* done */
-#define G1_ACTION_OP_DECLARE_1                     "G1_action_op_declare_1"                     /* done */
-#define G1_ACTION_OP_DECLARE_2                     "G1_action_op_declare_2"                     /* done */
-#define G1_ACTION_OP_DECLARE_3                     "G1_action_op_declare_3"                     /* done */
-#define G1_ACTION_PRIORITIES                       "G1_action_priorities"                       /* done */
-#define G1_ACTION_ALTERNATIVES                     "G1_action_alternatives"                     /* done */
-#define G1_ACTION_ALTERNATIVE                      "G1_action_alternative"                      /* done */
+#define G1_ACTION_PRIORITY_RULE                    "040_G1_action_priority_rule"                    /* done */
+#define G1_ACTION_QUANTIFIED_RULE                  "062_G1_action_quantified_rule"                  /* done */
+#define G1_ACTION_DISCARD_RULE                     "092_G1_action_discard_rule"                     /* done */
+#define G1_ACTION_DEFAULT_RULE                     "066_G1_action_default_rule"                     /* done */
+#define G1_ACTION_LEXEME_RULE                      "089_G1_action_lexeme_rule"                      /* done */
+#define G1_ACTION_TERMINAL_RULE                    "090_G1_action_terminal_rule"                    /* done */
+#define G1_ACTION_SYMBOL_RULE                      "091_G1_action_symbol_rule"                      /* done */
+#define G1_ACTION_COMPLETION_EVENT_DECLARATION_1   "093_G1_action_completion_event_declaration_1"   /* done */
+#define G1_ACTION_COMPLETION_EVENT_DECLARATION_2   "094_G1_action_completion_event_declaration_2"   /* done */
+#define G1_ACTION_NULLED_EVENT_DECLARATION_1       "095_G1_action_nulled_event_declaration_1"       /* done */
+#define G1_ACTION_NULLED_EVENT_DECLARATION_2       "096_G1_action_nulled_event_declaration_2"       /* done */
+#define G1_ACTION_PREDICTED_EVENT_DECLARATION_1    "097_G1_action_predicted_event_declaration_1"    /* done */
+#define G1_ACTION_PREDICTED_EVENT_DECLARATION_2    "098_G1_action_predicted_event_declaration_2"    /* done */
+#define G1_ACTION_INACCESSIBLE_STATEMENT           "056_G1_action_inaccessible_statement"           /* done */
+#define G1_ACTION_INACCESSIBLE_TREATMENT_1         "053_G1_action_inaccessible_treatment_1"         /* done */
+#define G1_ACTION_INACCESSIBLE_TREATMENT_2         "054_G1_action_inaccessible_treatment_2"         /* done */
+#define G1_ACTION_INACCESSIBLE_TREATMENT_3         "055_G1_action_inaccessible_treatment_3"         /* done */
+#define G1_ACTION_EXCEPTION_STATEMENT              "101_G1_action_exception_statement"
+#define G1_ACTION_AUTORANK_STATEMENT               "059_G1_action_autorank_statement"               /* done */
+#define G1_ACTION_OP_DECLARE_1                     "000_G1_action_op_declare_1"                     /* done */
+#define G1_ACTION_OP_DECLARE_2                     "001_G1_action_op_declare_2"                     /* done */
+#define G1_ACTION_OP_DECLARE_3                     "002_G1_action_op_declare_3"                     /* done */
+#define G1_ACTION_PRIORITIES                       "039_G1_action_priorities"                       /* done */
+#define G1_ACTION_ALTERNATIVES                     "038_G1_action_alternatives"                     /* done */
+#define G1_ACTION_ALTERNATIVE                      "037_G1_action_alternative"                      /* done */
 #define G1_ACTION_ADVERB_LIST                      "::shift" /* This is a nullable - it will return undef if there is no adverb */
-#define G1_ACTION_ADVERB_LIST_ITEMS                "G1_action_adverb_list_items"                /* done */
+#define G1_ACTION_ADVERB_LIST_ITEMS                "004_G1_action_adverb_list_items"                /* done */
 #define G1_ACTION_ADVERB_ITEM_01                   "::shift" /* <adverb item> ::= action */
 #define G1_ACTION_ADVERB_ITEM_02                   "::shift" /* <adverb item> ::= <left association> */
 #define G1_ACTION_ADVERB_ITEM_03                   "::shift" /* <adverb item> ::= <right association> */
@@ -305,77 +308,80 @@
 #define G1_ACTION_ADVERB_ITEM_21                   "::shift" /* <adverb item> ::= <fallback encoding> */
 #define G1_ACTION_ADVERB_ITEM_22                   "::shift" /* <adverb item> ::= <regex action> */
 #define G1_ACTION_ADVERB_ITEM_23                   "::shift" /* <adverb item> ::= <verbose specification> */
-#define G1_ACTION_ACTION_1                         "G1_action_action_1"                         /* done */
-#define G1_ACTION_ACTION_2                         "G1_action_action_2"                         /* done */
-#define G1_ACTION_ACTION_3                         "G1_action_action_3"                         /* done */
-#define G1_ACTION_SYMBOLACTION_1                   "G1_action_symbolaction_1"                   /* done */
-#define G1_ACTION_SYMBOLACTION_2                   "G1_action_symbolaction_2"                   /* done */
-#define G1_ACTION_SYMBOLACTION_3                   "G1_action_symbolaction_3"                   /* done */
-#define G1_ACTION_LEFT_ASSOCIATION                 "G1_action_left_association"                 /* done */
-#define G1_ACTION_RIGHT_ASSOCIATION                "G1_action_right_association"                /* done */
-#define G1_ACTION_GROUP_ASSOCIATION                "G1_action_group_association"                /* done */
-#define G1_ACTION_SEPARATOR_SPECIFICATION          "G1_action_separator_specification"          /* done */
-#define G1_ACTION_PROPER_SPECIFICATION_1           "G1_action_proper_specification_1"           /* done */
-#define G1_ACTION_PROPER_SPECIFICATION_2           "G1_action_proper_specification_2"           /* done */
-#define G1_ACTION_HIDESEPARATOR_SPECIFICATION_1    "G1_action_hideseparator_specification_1"    /* done */
-#define G1_ACTION_HIDESEPARATOR_SPECIFICATION_2    "G1_action_hideseparator_specification_2"    /* done */
-#define G1_ACTION_RANK_SPECIFICATION               "G1_action_rank_specification"               /* done */
-#define G1_ACTION_NULL_RANKING_SPECIFICATION_1     "G1_action_null_ranking_specification_1"     /* done */
-#define G1_ACTION_NULL_RANKING_SPECIFICATION_2     "G1_action_null_ranking_specification_2"     /* done */
-#define G1_ACTION_NULL_RANKING_CONSTANT_1          "G1_action_null_ranking_constant_1"          /* done */
-#define G1_ACTION_NULL_RANKING_CONSTANT_2          "G1_action_null_ranking_constant_2"          /* done */
-#define G1_ACTION_PRIORITY_SPECIFICATION           "G1_action_priority_specification"           /* done */
-#define G1_ACTION_PAUSE_SPECIFICATION_1            "G1_action_pause_specification_1"            /* done */
-#define G1_ACTION_PAUSE_SPECIFICATION_2            "G1_action_pause_specification_2"            /* done */
-#define G1_ACTION_EVENT_SPECIFICATION              "G1_action_event_specification"              /* done */
-#define G1_ACTION_EVENT_INITIALIZATION             "G1_action_event_initialization"             /* done */
-#define G1_ACTION_EVENT_INITIALIZER_1              "G1_action_event_initializer_1"              /* done */
-#define G1_ACTION_ON_OR_OFF_1                      "G1_action_on_or_off_1"                      /* done */
-#define G1_ACTION_ON_OR_OFF_2                      "G1_action_on_or_off_2"                      /* done */
-#define G1_ACTION_EVENT_INITIALIZER_2              "G1_action_event_initializer_2"              /* done */
-#define G1_ACTION_LATM_SPECIFICATION_1             "G1_action_latm_specification_1"             /* done */
-#define G1_ACTION_LATM_SPECIFICATION_2             "G1_action_latm_specification_2"             /* done */
-#define G1_ACTION_VERBOSE_SPECIFICATION_1          "G1_action_verbose_specification_1"           /* done */
-#define G1_ACTION_VERBOSE_SPECIFICATION_2          "G1_action_verbose_specification_2"           /* done */
-#define G1_ACTION_NAMING                           "G1_action_naming"                           /* done */
+#define G1_ACTION_ADVERB_ITEM_24                   "::shift" /* <adverb item> ::= <discard is fallback specification> */
+#define G1_ACTION_ACTION_1                         "005_G1_action_action_1"                         /* done */
+#define G1_ACTION_ACTION_2                         "006_G1_action_action_2"                         /* done */
+#define G1_ACTION_ACTION_3                         "007_G1_action_action_3"                         /* done */
+#define G1_ACTION_SYMBOLACTION_1                   "013_G1_action_symbolaction_1"                   /* done */
+#define G1_ACTION_SYMBOLACTION_2                   "014_G1_action_symbolaction_2"                   /* done */
+#define G1_ACTION_SYMBOLACTION_3                   "015_G1_action_symbolaction_3"                   /* done */
+#define G1_ACTION_LEFT_ASSOCIATION                 "016_G1_action_left_association"                 /* done */
+#define G1_ACTION_RIGHT_ASSOCIATION                "017_G1_action_right_association"                /* done */
+#define G1_ACTION_GROUP_ASSOCIATION                "018_G1_action_group_association"                /* done */
+#define G1_ACTION_SEPARATOR_SPECIFICATION          "019_G1_action_separator_specification"          /* done */
+#define G1_ACTION_PROPER_SPECIFICATION_1           "071_G1_action_proper_specification_1"           /* done */
+#define G1_ACTION_PROPER_SPECIFICATION_2           "072_G1_action_proper_specification_2"           /* done */
+#define G1_ACTION_HIDESEPARATOR_SPECIFICATION_1    "075_G1_action_hideseparator_specification_1"    /* done */
+#define G1_ACTION_HIDESEPARATOR_SPECIFICATION_2    "076_G1_action_hideseparator_specification_2"    /* done */
+#define G1_ACTION_RANK_SPECIFICATION               "077_G1_action_rank_specification"               /* done */
+#define G1_ACTION_NULL_RANKING_SPECIFICATION_1     "078_G1_action_null_ranking_specification_1"     /* done */
+#define G1_ACTION_NULL_RANKING_SPECIFICATION_2     "079_G1_action_null_ranking_specification_2"     /* done */
+#define G1_ACTION_NULL_RANKING_CONSTANT_1          "080_G1_action_null_ranking_constant_1"          /* done */
+#define G1_ACTION_NULL_RANKING_CONSTANT_2          "081_G1_action_null_ranking_constant_2"          /* done */
+#define G1_ACTION_PRIORITY_SPECIFICATION           "084_G1_action_priority_specification"           /* done */
+#define G1_ACTION_PAUSE_SPECIFICATION_1            "082_G1_action_pause_specification_1"            /* done */
+#define G1_ACTION_PAUSE_SPECIFICATION_2            "083_G1_action_pause_specification_2"            /* done */
+#define G1_ACTION_EVENT_SPECIFICATION              "088_G1_action_event_specification"              /* done */
+#define G1_ACTION_EVENT_INITIALIZATION             "087_G1_action_event_initialization"             /* done */
+#define G1_ACTION_EVENT_INITIALIZER_1              "085_G1_action_event_initializer_1"              /* done */
+#define G1_ACTION_ON_OR_OFF_1                      "057_G1_action_on_or_off_1"                      /* done */
+#define G1_ACTION_ON_OR_OFF_2                      "058_G1_action_on_or_off_2"                      /* done */
+#define G1_ACTION_EVENT_INITIALIZER_2              "086_G1_action_event_initializer_2"              /* done */
+#define G1_ACTION_LATM_SPECIFICATION_1             "067_G1_action_latm_specification_1"             /* done */
+#define G1_ACTION_LATM_SPECIFICATION_2             "068_G1_action_latm_specification_2"             /* done */
+#define G1_ACTION_DISCARD_IS_FALLBACK_SPECIFICATION_1 "069_G1_action_discard_is_fallback_specification_1" /* done */
+#define G1_ACTION_DISCARD_IS_FALLBACK_SPECIFICATION_2 "070_G1_action_discard_is_fallback_specification_2" /* done */
+#define G1_ACTION_VERBOSE_SPECIFICATION_1          "073_G1_action_verbose_specification_1"           /* done */
+#define G1_ACTION_VERBOSE_SPECIFICATION_2          "074_G1_action_verbose_specification_2"           /* done */
+#define G1_ACTION_NAMING                           "100_G1_action_naming"                            /* done */
 #define G1_ACTION_NULL_ADVERB                      "::undef"
 #define G1_ACTION_ALTERNATIVE_NAME_1               "::shift" /* <alternative name> ::= <standard name> */
-#define G1_ACTION_ALTERNATIVE_NAME_2               "G1_action_alternative_name_2"               /* done */
+#define G1_ACTION_ALTERNATIVE_NAME_2               "099_G1_action_alternative_name_2"               /* done */
 #define G1_ACTION_EVENT_NAME_1                     "::ascii" /* <event name> ::= <ascii graph name> */
 #define G1_ACTION_EVENT_NAME_2                     "::ascii" /* <event name> ::= ':symbol' */
 #define G1_ACTION_EVENT_NAME_3                     "::ascii" /* <event name> ::= ':discard[on]' */
 #define G1_ACTION_EVENT_NAME_4                     "::ascii" /* <event name> ::= ':discard[off]' */
 #define G1_ACTION_EVENT_NAME_5                     "::ascii" /* <event name> ::= ':discard[switch]' */
-#define G1_ACTION_LHS_1                            "G1_action_lhs_1" /* lhs ::= <symbol name> */
-#define G1_ACTION_LHS_2                            "G1_action_lhs_2" /* lhs ::= <lhs> /\-\-?\(/ <lua optional parlist after lparen> */
-#define G1_ACTION_RHS                              "G1_action_rhs"                              /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_1                "G1_action_rhs_alternative_1"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_2                "G1_action_rhs_alternative_2"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_3                "G1_action_rhs_alternative_3"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_4                "G1_action_rhs_alternative_4"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_5                "G1_action_rhs_alternative_5"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_6                "G1_action_rhs_alternative_6"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_7                "G1_action_rhs_alternative_7"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_8                "G1_action_rhs_alternative_8"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_9                "G1_action_rhs_alternative_9"                /* done */
-#define G1_ACTION_RHS_ALTERNATIVE_10               "G1_action_rhs_alternative_10"               /* done */
-#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_1       "G1_action_rhs_primary_no_parameter_1"       /* done */
-#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_2       "G1_action_rhs_primary_no_parameter_2"       /* done */
-#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_3       "G1_action_rhs_primary_no_parameter_3"       /* done */
+#define G1_ACTION_LHS_1                            "112_G1_action_lhs_1" /* lhs ::= <symbol name> */
+#define G1_ACTION_LHS_2                            "113_G1_action_lhs_2" /* lhs ::= <lhs> /\-\-?\(/ <lua optional parlist after lparen> */
+#define G1_ACTION_RHS                              "003_G1_action_rhs"                              /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_1                "022_G1_action_rhs_alternative_1"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_2                "023_G1_action_rhs_alternative_2"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_3                "024_G1_action_rhs_alternative_3"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_4                "025_G1_action_rhs_alternative_4"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_5                "026_G1_action_rhs_alternative_5"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_6                "027_G1_action_rhs_alternative_6"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_7                "028_G1_action_rhs_alternative_7"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_8                "029_G1_action_rhs_alternative_8"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_9                "030_G1_action_rhs_alternative_9"                /* done */
+#define G1_ACTION_RHS_ALTERNATIVE_10               "031_G1_action_rhs_alternative_10"               /* done */
+#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_1       "032_G1_action_rhs_primary_no_parameter_1"       /* done */
+#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_2       "033_G1_action_rhs_primary_no_parameter_2"       /* done */
+#define G1_ACTION_RHS_PRIMARY_NO_PARAMETER_3       "034_G1_action_rhs_primary_no_parameter_3"       /* done */
 #define G1_ACTION_RHS_PRIMARY_1                    "::shift"                                    /* done */
-#define G1_ACTION_RHS_PRIMARY_2                    "G1_action_rhs_primary_2"                    /* done */
-#define G1_ACTION_RHS_PRIMARY_3                    "G1_action_rhs_primary_3"                    /* done */
-#define G1_ACTION_SINGLE_SYMBOL_1                  "G1_action_single_symbol_1"                  /* done */
-#define G1_ACTION_SINGLE_SYMBOL_2                  "G1_action_single_symbol_2"                  /* done */
-#define G1_ACTION_TERMINAL_1                       "G1_action_terminal_1"                       /* done */
-#define G1_ACTION_TERMINAL_2                       "G1_action_terminal_2"                       /* done */
-#define G1_ACTION_TERMINAL_3                       "G1_action_terminal_3"                       /* done */
-#define G1_ACTION_TERMINAL_4                       "G1_action_terminal_4"                       /* done */
-#define G1_ACTION_TERMINAL_5                       "G1_action_terminal_5"                       /* done */
-#define G1_ACTION_TERMINAL_6                       "G1_action_terminal_6"                       /* done */
-#define G1_ACTION_SYMBOL                           "G1_action_symbol" /* symbol ::= <symbol name> */
-#define G1_ACTION_SYMBOL_NAME_1                    "G1_action_symbol_name_1" /* <symbol name> ::= <bare name> */
-#define G1_ACTION_SYMBOL_NAME_2                    "G1_action_symbol_name_2" /* <symbol name> ::= <bracketed name> */ /* done */
+#define G1_ACTION_RHS_PRIMARY_2                    "035_G1_action_rhs_primary_2"                    /* done */
+#define G1_ACTION_RHS_PRIMARY_3                    "036_G1_action_rhs_primary_3"                    /* done */
+#define G1_ACTION_SINGLE_SYMBOL_1                  "041_G1_action_single_symbol_1"                  /* done */
+#define G1_ACTION_SINGLE_SYMBOL_2                  "042_G1_action_single_symbol_2"                  /* done */
+#define G1_ACTION_TERMINAL_1                       "043_G1_action_terminal_1"                       /* done */
+#define G1_ACTION_TERMINAL_2                       "044_G1_action_terminal_2"                       /* done */
+#define G1_ACTION_TERMINAL_3                       "045_G1_action_terminal_3"                       /* done */
+#define G1_ACTION_TERMINAL_4                       "046_G1_action_terminal_4"                       /* done */
+#define G1_ACTION_TERMINAL_5                       "047_G1_action_terminal_5"                       /* done */
+#define G1_ACTION_TERMINAL_6                       "048_G1_action_terminal_6"                       /* done */
+#define G1_ACTION_SYMBOL                           "049_G1_action_symbol" /* symbol ::= <symbol name> */
+#define G1_ACTION_SYMBOL_NAME_1                    "020_G1_action_symbol_name_1" /* <symbol name> ::= <bare name> */
+#define G1_ACTION_SYMBOL_NAME_2                    "021_G1_action_symbol_name_2" /* <symbol name> ::= <bracketed name> */ /* done */
 #define G1_ACTION_ACTION_NAME_1                    "::ascii" /* <action name> ::= <ascii graph name> */
 #define G1_ACTION_ACTION_NAME_2                    "::ascii" /* <action name> ::= '::shift' */
 #define G1_ACTION_ACTION_NAME_3                    "::ascii" /* <action name> ::= '::undef' */
@@ -403,52 +409,52 @@
 #define G1_ACTION_SYMBOLACTION_NAME_10             "::ascii" /* <symbol action name> ::= '::json' */
 #define G1_ACTION_SYMBOLACTION_NAME_11             "::ascii" /* <symbol action name> ::= '::jsonf' */
 #define G1_ACTION_SYMBOLACTION_NAME_12             "::shift" /* <symbol action name> ::= <lua function> */
-#define G1_ACTION_QUANTIFIER_1                     "G1_action_quantifier_1"                     /* done */
-#define G1_ACTION_QUANTIFIER_2                     "G1_action_quantifier_2"                     /* done */
+#define G1_ACTION_QUANTIFIER_1                     "060_G1_action_quantifier_1"                     /* done */
+#define G1_ACTION_QUANTIFIER_2                     "061_G1_action_quantifier_2"                     /* done */
 #define G1_ACTION_SIGNED_INTEGER                   "::ascii" /* <signed integer> ::= /[+-]?\d+/ */
 #define G1_ACTION_UNSIGNED_INTEGER                 "::ascii" /* <unsigned integer> ::= /\d+/ */
-#define G1_ACTION_GRAMMAR_REFERENCE_1              "G1_action_grammar_reference_1"              /* done */
-#define G1_ACTION_GRAMMAR_REFERENCE_2              "G1_action_grammar_reference_2"              /* done */
-#define G1_ACTION_GRAMMAR_REFERENCE_3              "G1_action_grammar_reference_3"              /* done */
-#define G1_ACTION_STRING_LITERAL                   "G1_action_string_literal"                   /* done */
+#define G1_ACTION_GRAMMAR_REFERENCE_1              "050_G1_action_grammar_reference_1"              /* done */
+#define G1_ACTION_GRAMMAR_REFERENCE_2              "051_G1_action_grammar_reference_2"              /* done */
+#define G1_ACTION_GRAMMAR_REFERENCE_3              "052_G1_action_grammar_reference_3"              /* done */
+#define G1_ACTION_STRING_LITERAL                   "008_G1_action_string_literal"                   /* done */
 #define G1_ACTION_STRING_LITERAL_UNIT              "::copy[2]" /* <string literal unit> ::= '::u8"' <switch :discard off> <string literal inside many> '"' <switch :discard on> */
 #define G1_ACTION_STRING_LITERAL_INSIDE_ANY        "::concat" /* <string literal inside any> ::= <string literal inside>* */
 #define G1_ACTION_STRING_LITERAL_INSIDE_1          "::shift" /* <string literal inside> ::= /[^"\\\n]/ */
-#define G1_ACTION_STRING_LITERAL_INSIDE_2          "G1_action_string_literal_inside_2"          /* done */
-#define G1_ACTION_STRING_LITERAL_INSIDE_3          "G1_action_string_literal_inside_3"          /* done */
-#define G1_ACTION_STRING_LITERAL_INSIDE_4          "G1_action_string_literal_inside_4"          /* done */
-#define G1_ACTION_STRING_LITERAL_INSIDE_5          "G1_action_string_literal_inside_5"          /* done */
+#define G1_ACTION_STRING_LITERAL_INSIDE_2          "009_G1_action_string_literal_inside_2"          /* done */
+#define G1_ACTION_STRING_LITERAL_INSIDE_3          "010_G1_action_string_literal_inside_3"          /* done */
+#define G1_ACTION_STRING_LITERAL_INSIDE_4          "011_G1_action_string_literal_inside_4"          /* done */
+#define G1_ACTION_STRING_LITERAL_INSIDE_5          "012_G1_action_string_literal_inside_5"          /* done */
 #define G1_ACTION_DISCARD_ON                       "::undef"
 #define G1_ACTION_DISCARD_OFF                      "::undef"
-#define G1_ACTION_LUASCRIPT_STATEMENT              "G1_action_luascript_statement"
+#define G1_ACTION_LUASCRIPT_STATEMENT              "102_G1_action_luascript_statement"
 #define G1_ACTION_LUASCRIPT_SOURCE                 "::concat"
 #define G1_ACTION_IFACTION_NAME_1                  "::ascii" /* <if action name> ::= <ascii graph name> */
 #define G1_ACTION_IFACTION_NAME_2                  "::ascii" /* <if action name> ::= <lua action name> */
 #define G1_ACTION_IFACTION_NAME_3                  "::shift" /* <if action name> ::= <lua function> */
-#define G1_ACTION_IFACTION                         "G1_action_ifaction"                         /* done */
+#define G1_ACTION_IFACTION                         "103_G1_action_ifaction"                         /* done */
 #define G1_ACTION_GENERATORACTION_NAME_1           "::ascii" /* <generator action name> ::= <ascii graph name> */
 #define G1_ACTION_GENERATORACTION_NAME_2           "::ascii" /* <generator action name> ::= <lua action name> */
 #define G1_ACTION_GENERATORACTION_NAME_3           "::shift" /* <generator action name> ::= <lua function> */
-#define G1_ACTION_GENERATORACTION                  "G1_action_generatoraction"                         /* done */
+#define G1_ACTION_GENERATORACTION                  "105_G1_action_generatoraction"                         /* done */
 #define G1_ACTION_REGEXACTION_NAME_1               "::ascii" /* <regex action name> ::= <ascii graph name> */
 #define G1_ACTION_REGEXACTION_NAME_2               "::ascii" /* <regex action name> ::= <lua action name> */
 #define G1_ACTION_REGEXACTION_NAME_3               "::shift" /* <regex action name> ::= <lua function> */
-#define G1_ACTION_REGEXACTION                      "G1_action_regexaction"                       /* done */
+#define G1_ACTION_REGEXACTION                      "104_G1_action_regexaction"                       /* done */
 #define G1_ACTION_GENERATORACTION_NAME_1           "::ascii" /* <generator action name> ::= <ascii graph name> */
 #define G1_ACTION_GENERATORACTION_NAME_2           "::ascii" /* <generator action name> ::= <lua action name> */
 #define G1_ACTION_GENERATORACTION_NAME_3           "::shift" /* <generator action name> ::= <lua function> */
-#define G1_ACTION_GENERATORACTION                  "G1_action_generatoraction"                       /* done */
+#define G1_ACTION_GENERATORACTION                  "105_G1_action_generatoraction"                       /* done */
 #define G1_ACTION_EVENTACTION_NAME_1               "::ascii" /* <event action name> ::= <ascii graph name> */
 #define G1_ACTION_EVENTACTION_NAME_2               "::ascii" /* <event action name> ::= <lua identifier> */
 #define G1_ACTION_EVENTACTION_NAME_3               "::shift" /* <event action name> ::= <lua function> */
-#define G1_ACTION_EVENTACTION                      "G1_action_eventaction"                   /* done */
-#define G1_ACTION_DEFAULTENCODING                  "G1_action_defaultencoding"                   /* done */
+#define G1_ACTION_EVENTACTION                      "106_G1_action_eventaction"                   /* done */
+#define G1_ACTION_DEFAULTENCODING                  "107_G1_action_defaultencoding"                   /* done */
 #define G1_ACTION_DEFAULTENCODING_NAME             "::ascii" /* <default encoding name> ::= <ascii graph name> */
-#define G1_ACTION_FALLBACKENCODING                 "G1_action_fallbackencoding"                   /* done */
+#define G1_ACTION_FALLBACKENCODING                 "108_G1_action_fallbackencoding"                   /* done */
 #define G1_ACTION_FALLBACKENCODING_NAME            "::ascii" /* <fallback encoding name> ::= <ascii graph name> */
-#define G1_ACTION_LUA_FUNCTION                     "G1_action_lua_function" /* <lua function>> ::= '::lua->function(' <lua function after lparen>@+2 */
-#define G1_ACTION_LUA_FUNCTIONCALL                 "G1_action_lua_functioncall" /* <lua functioncall>> ::= '->(' <lua args after lparen>@+2 */
-#define G1_ACTION_LUA_FUNCTIONDECL                 "G1_action_lua_functiondecl" /* <lua functiondecl>> ::= '<-(' <lua args after lparen>@+2 */
+#define G1_ACTION_LUA_FUNCTION                     "109_G1_action_lua_function" /* <lua function>> ::= '::lua->function(' <lua function after lparen>@+2 */
+#define G1_ACTION_LUA_FUNCTIONCALL                 "110_G1_action_lua_functioncall" /* <lua functioncall>> ::= '->(' <lua args after lparen>@+2 */
+#define G1_ACTION_LUA_FUNCTIONDECL                 "111_G1_action_lua_functiondecl" /* <lua functiondecl>> ::= '<-(' <lua args after lparen>@+2 */
 
 typedef struct bootstrap_grammar_terminal {
   int                        idi;                 /* Identifier */
