@@ -304,6 +304,7 @@ struct marpaESLIF_grammar {
   marpaESLIF_string_t   *descp;                              /* Grammar description */
   short                  descautob;                          /* True if alternative name was autogenerated */
   short                  latmb;                              /* Longest acceptable token match mode */
+  short                  discardIsFallbackb;                 /* discard is fallback mode */
   marpaWrapperGrammar_t *marpaWrapperGrammarStartp;          /* Grammar implementation at :start */
   marpaWrapperGrammar_t *marpaWrapperGrammarStartNoEventp;   /* Grammar implementation at :start forcing no event */
   size_t                 nTerminall;                         /* Total number of grammar terminals */
@@ -468,6 +469,7 @@ struct marpaESLIFValue {
   genericLogger_t             *stringGeneratorLoggerp; /* Internal string generator logger, put here to avoid unnecessary genericLogger_newp()/genericLogger_freev() calls */
   char                        *luaprecompiledp;    /* Lua script source precompiled */
   size_t                       luaprecompiledl;    /* Lua script source precompiled length in byte */
+  short                        hideSeparatorb;     /* Hook for internal ::row and ::table actions to process more efficiently hide-separator adverb */
 };
 
 struct marpaESLIF_stream {
@@ -591,10 +593,10 @@ struct marpaESLIFRecognizer {
   /* For _marpaESLIFRecognizer_set_internalp_deepb */
   genericStack_t               _marpaESLIFValueResultWorkStack;
   genericStack_t              *marpaESLIFValueResultWorkStackp;
-  genericStack_t               _marpaESLIFValueResultStack;
-  genericStack_t              *marpaESLIFValueResultStackp;
-  genericStack_t               _marpaESLIFValueResultStackArray[MARPAESLIF_HASH_SIZE];
-  genericStack_t              *marpaESLIFValueResultStackArrayp; /* Only the top recognizer owns it */
+  genericStack_t               _marpaESLIFValueResultStackOrig;
+  genericStack_t              *marpaESLIFValueResultStackOrigp;
+  genericStack_t               _marpaESLIFValueResultStackNew;
+  genericStack_t              *marpaESLIFValueResultStackNewp;
 
   /* When doing regex callback, only the "offset_vector" part is variable, all other */
   /* members of the regex's TABLE argument can be created once and modified in-place */
